Displays the current status of the LM Studio local server via the CLI, including whether it is running and its configuration.
Value
By default, returns a character vector containing the raw CLI output.
If json = TRUE and the jsonlite package is available, it
returns a parsed list or data.frame of the status configuration.
Examples
if (FALSE) { # \dontrun{
lms_server_start()
# Get basic status string
lms_server_status()
# Get status as a parsed JSON data frame
lms_server_status(json = TRUE)
} # }