Learn R Programming

rlmstudio (version 0.2.2)

print.lms_chat_result: Print an LM Studio chat result

Description

Custom print method for responses that include log probabilities. Displays the text clearly and provides a summary of the metadata.

Usage

# S3 method for lms_chat_result
print(x, ...)

Value

Invisibly returns the input object x.

Arguments

x

An object of class lms_chat_result.

...

Additional arguments passed to print.