Learn R Programming

rlmstudio (version 0.2.2)

rlmstudio-package: rlmstudio: Access and Control LM Studio

Description

A community-maintained 'R' wrapper for the 'LM Studio' command line interface and API. Provides functions to manage the local daemon and server, download and load models, and interact with Large Language Models (LLMs).

Arguments

Author

Maintainer: Jeffrey Girard me@jmgirard.com (ORCID) [copyright holder]

Authors:

See Also