On desktop operating systems (macOS and Windows),
running this command may actually launch the LM Studio desktop application
to act as the backend engine. If the GUI is already open, this function
will simply detect the active instance and return successfully. While safe
to use, desktop users generally do not need to call this function and can
just open the application manually.