Learn R Programming

rlmstudio (version 0.2.2)

lms_daemon_stop: Stop the LM Studio headless daemon

Description

Stops the llmster daemon via the CLI. Use this to clean up system resources when you are completely finished using LM Studio in headless mode.

Usage

lms_daemon_stop(force = FALSE)

Value

Invisibly returns the system exit code (0 for success).

Arguments

force

Logical. If TRUE, attempts to stop the local server before shutting down the daemon. The daemon cannot be stopped while the server is actively running. Defaults to FALSE.

Desktop Users

If the daemon is currently being managed by the LM Studio desktop application, this function will fail. The CLI intentionally prevents programmatic shutdowns of the GUI to avoid disrupting visual sessions. In this scenario, you must close the desktop application manually.

Examples

Run this code
if (FALSE) {
lms_daemon_stop(force = TRUE)
}

Run the code above in your browser using DataLab