Learn R Programming

rlmstudio (version 0.2.2)

lms_server_start: Start the LM Studio local server

Description

Launches the LM Studio local server via the CLI, allowing you to interact with loaded models via HTTP API calls.

Usage

lms_server_start(port = NULL, cors = FALSE)

Value

Invisibly returns an integer representing the system exit code (0 for success).

Arguments

port

Integer. Port to run the server on. If not provided, LM Studio uses the last used port.

cors

Logical. Enable CORS support for web application development. Defaults to FALSE.

See Also

Examples

Run this code
if (FALSE) {
# Start server on the default port
lms_server_start()

# Start server on a custom port with CORS enabled
lms_server_start(port = 8080, cors = TRUE)
}

Run the code above in your browser using DataLab