Displays the current status of the LM Studio local server via the CLI, including whether it is running and its configuration.
Value
A character vector of the raw CLI output. If json = TRUE and the
jsonlite package is installed, it returns a parsed list or data frame.
Examples
if (FALSE) { # \dontrun{
lms_server_start()
# Get basic status string
lms_server_status()
# Get status as a parsed JSON data frame
lms_server_status(json = TRUE)
} # }