Learn R Programming

rlmstudio (version 0.2.2)

lms_server_status: Check the status of the LM Studio server

Description

Displays the current status of the LM Studio local server via the CLI, including whether it is running and its configuration.

Usage

lms_server_status(
  json = FALSE,
  verbose = FALSE,
  quiet = FALSE,
  log_level = NULL
)

Value

By default, returns a character vector containing the raw CLI output. If json = TRUE and the jsonlite package is available, it returns a parsed list or data.frame of the status configuration.

Arguments

json

Logical. Output the status in machine-readable JSON format.

verbose

Logical. Enable detailed logging output.

quiet

Logical. Suppress all logging output.

log_level

Character. The level of logging to use (e.g., "info", "debug").

Details

You can only use one logging control flag at a time (verbose, quiet, or log_level).

See Also

Examples

Run this code
if (FALSE) {
lms_server_start()

# Get basic status string
lms_server_status()

# Get status as a parsed JSON data frame
lms_server_status(json = TRUE)
}

Run the code above in your browser using DataLab