By default, returns a character vector containing the raw CLI output.
If json = TRUE and the jsonlite package is available, it
returns a parsed list or data.frame of the status configuration.
Arguments
json
Logical. Output the status in machine-readable JSON format.
verbose
Logical. Enable detailed logging output.
quiet
Logical. Suppress all logging output.
log_level
Character. The level of logging to use (e.g., "info",
"debug").
Details
You can only use one logging control flag at a time (verbose,
quiet, or log_level).