Retrieves a list of all currently loaded models and unloads them one by one.
Value
Invisibly returns a character vector of the unloaded model instance identifiers, or NULL if no models were loaded.
Examples
if (FALSE) { # \dontrun{
lms_server_start()
lms_download("google/gemma-3-1b")
lms_load("google/gemma-3-1b")
# Unload all currently loaded models to clear VRAM
lms_unload_all()
} # }