Learn R Programming

rlmstudio (version 0.2.2)

lms_unload_all: Unload all models from memory

Description

Retrieves a list of all currently loaded models and unloads them one by one.

Usage

lms_unload_all(host = "http://localhost:1234", ...)

Value

Invisibly returns a character vector of the instance_ids that were successfully unloaded. If no models were currently loaded, it invisibly returns NULL.

Arguments

host

Character. The host address of the local server. Defaults to "http://localhost:1234".

...

Additional arguments passed to the API request body for each unload request.

See Also

lms_unload

Examples

Run this code
if (FALSE) {
lms_server_start()
lms_download("google/gemma-3-1b")
lms_load("google/gemma-3-1b")

# Unload all currently loaded models to clear VRAM
lms_unload_all()
}

Run the code above in your browser using DataLab