A community-maintained 'R' wrapper for the 'LM Studio' command line interface and API. Provides functions to manage the local daemon and server, download and load models, and interact with Large Language Models (LLMs).
Maintainer: Jeffrey Girard me@jmgirard.com (ORCID) [copyright holder]
Authors:
Jeffrey Girard me@jmgirard.com (ORCID) [copyright holder]
Useful links: